@@ -7,8 +7,8 @@ docs.  In setup.py in particular, we exec this file, so it cannot import dipy
 # full release.  '.dev' as a _version_extra string means this is a development
 # version
 _version_major = 0
-_version_minor = 7
-_version_micro = 1
+_version_minor = 8
+_version_micro = 0
 _version_extra = ''
 #_version_extra = ''
 
@@ -29,11 +29,11 @@ CLASSIFIERS = ["Development Status :: 3 - Alpha",
 description  = 'Diffusion MRI utilities in python'
 
 # Note: this long_description is actually a copy/paste from the top-level
-# README.txt, so that it shows up nicely on PyPI.  So please remember to edit
+# README.rst, so that it shows up nicely on PyPI.  So please remember to edit
 # it only in one place and sync it correctly.
 long_description = """
 ======
- DiPy
+ DIPY
 ======
 
 Dipy is a python toolbox for analysis of MR diffusion imaging.
@@ -44,13 +44,13 @@ clinical decisions.
 Website
 =======
 
-Current information can always be found at the NIPY dipy website -
-http://nipy.org/dipy - or directly from the DIPY website - http://dipy.org
+Current information can always be found from the dipy website - http://dipy.org
 
 Mailing Lists
 =============
 
-Please see the developer's list at http://mail.scipy.org/mailman/listinfo/nipy-devel
+Please see the developer's list at
+http://mail.scipy.org/mailman/listinfo/nipy-devel
 
 Code
 ====
@@ -63,21 +63,25 @@ You can find our sources and single-click downloads:
 
 .. _main repository: http://github.com/nipy/dipy
 .. _Documentation: http://dipy.org
-.. _current trunk: https://github.com/nipy/dipy/archive/master.zip
+.. _current trunk: http://github.com/nipy/dipy/archives/master
 
 License
 =======
 
-dipy is licensed under the terms of the BSD license. Some code included with
-dipy is also licensed under the BSD license.  Please the LICENSE file in the
-dipy distribution.
+Dipy is licensed under the terms of the BSD license.
+Please see the LICENSE file in the dipy distribution.
+
+Dipy uses other libraries also licensed under the BSD or the
+MIT licenses, with the only exception of the SHORE module which
+optionally uses the cvxopt library. Cvxopt is licensed
+under the GPL license.
 """
 
 # versions for dependencies
-NUMPY_MIN_VERSION='1.3'
-SCIPY_MIN_VERSION='0.7.2'
-CYTHON_MIN_VERSION='0.17'
-NIBABEL_MIN_VERSION='1.0.0'
+NUMPY_MIN_VERSION='1.6'
+SCIPY_MIN_VERSION='0.9'
+CYTHON_MIN_VERSION='0.18'
+NIBABEL_MIN_VERSION='1.2.0'
 
 # Main setup parameters
 NAME                = 'dipy'
